Merge branch 'v4.7.x' into master
authorArun Persaud <arun@nubati.net>
Sun, 5 Jan 2014 18:51:08 +0000 (10:51 -0800)
committerArun Persaud <arun@nubati.net>
Sun, 5 Jan 2014 18:51:08 +0000 (10:51 -0800)
Conflicts:
dialogs.c
gtk/xboard.c
gtk/xoptions.c
po/es.po
winboard/config.h
winboard/winboard.c

95 files changed:
COPYRIGHT
README
args.h
autogen.sh
backend.c
backend.h
backendz.h
board.c
board.h
book.c
childio.c
childio.h
cmail.in
common.h
configure.ac
copyright.texi
dialogs.c
dialogs.h
doc-maint/release.org
draw.c
draw.h
engineoutput.c
engineoutput.h
evalgraph.c
evalgraph.h
frontend.h
gamelist.c
gtk/xboard.c
gtk/xboard.h
gtk/xengineoutput.c
gtk/xoptions.c
gtk/xtimer.c
history.c
lists.c
lists.h
menus.c
menus.h
moves.c
moves.h
nengineoutput.c
nevalgraph.c
ngamelist.c
nhistory.c
parser.c
parser.h
pgntags.c
po/lng2po.sh
po/ru.po
themes/xiangqi/.DS_Store [deleted file]
uci.c
usounds.c
usystem.c
usystem.h
winboard/defaults.h
winboard/help.c
winboard/help/html/24.htm
winboard/jaws.c
winboard/language.txt
winboard/language/deutsch.lng
winboard/language/italiano.lng
winboard/language/nederlands.lng
winboard/language/romanian.lng
winboard/language/russian.lng
winboard/language/spanish.lng
winboard/language/vietnamese.lng
winboard/wchat.c
winboard/wclipbrd.c
winboard/wclipbrd.h
winboard/wedittags.c
winboard/wengineoutput.c
winboard/wevalgraph.c
winboard/wgamelist.c
winboard/whistory.c
winboard/winboard.c
winboard/winboard.h
winboard/winboard.rc
winboard/wlayout.c
winboard/woptions.c
winboard/woptions.h
winboard/wsettings.c
winboard/wsockerr.c
winboard/wsockerr.h
xaw/xboard.c
xaw/xboard.h
xaw/xengineoutput.c
xaw/xgamelist.c
xaw/xgamelist.h
xaw/xhistory.c
xaw/xhistory.h
xaw/xoptions.c
xboard2.h
zippy.README
zippy.c
zippy.h
zippy.lines

index d6f6a4d..216885a 100644 (file)
--- a/COPYRIGHT
+++ b/COPYRIGHT
@@ -4,10 +4,10 @@ Original authors:  Dan Sears and Chris Sears
 Enhancements (Version 2.0 and later):  Tim Mann
 
 Copyright 1991 by Digital Equipment Corporation, Maynard,
-Massachusetts.  
+Massachusetts.
 
 Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006, 2007,
-2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
 
 Enhancements Copyright 2005 Alessandro Scotti
 
diff --git a/README b/README
index 2be9ee5..ce3c783 100644 (file)
--- a/README
+++ b/README
@@ -1,10 +1,10 @@
 What is XBoard?
 ===============
 XBoard is a graphical chessboard for the X Window System.  It can
-serve as a user interface for chess engines such as Fairy-Max, 
-Crafty or GNU Chess, for the Internet Chess Server, or for electronic 
-mail correspondence chess. It supports all major forms of chess, such 
-as international chess, xiangqi and shogi. XBoard can also be used by 
+serve as a user interface for chess engines such as Fairy-Max,
+Crafty or GNU Chess, for the Internet Chess Server, or for electronic
+mail correspondence chess. It supports all major forms of chess, such
+as international chess, xiangqi and shogi. XBoard can also be used by
 itself as viewer for stored chess games.  See the manual page for
 further details.
 
@@ -71,4 +71,3 @@ Here is a sample of approximately what you should type (on Unix):
 If you improve XBoard, please send a message about your changes, and
 we will get in touch with you about merging them in to the main line
 of development.
-
diff --git a/args.h b/args.h
index 23c166a..d1463ec 100644 (file)
--- a/args.h
+++ b/args.h
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
  *
index 9e86c22..491191e 100755 (executable)
@@ -2,7 +2,7 @@
 
 # This file is part of GNU XBoard.
 #
-# Copyright 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+# Copyright 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
 #
 # GNU XBoard is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
index 96458f2..084c42c 100644 (file)
--- a/backend.c
+++ b/backend.c
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
  *
@@ -8053,6 +8053,7 @@ Adjudicate (ChessProgramState *cps)
              case MT_NONE:
              default:
                break;
+             case MT_STEALMATE:
              case MT_STALEMATE:
              case MT_STAINMATE:
                reason = "Xboard adjudication: Stalemate";
@@ -12195,22 +12196,40 @@ void
 PackMove (int fromX, int fromY, int toX, int toY, ChessSquare promoPiece)
 {
     int sq = fromX + (fromY<<4);
-    int piece = quickBoard[sq];
+    int piece = quickBoard[sq], rook;
     quickBoard[sq] = 0;
     moveDatabase[movePtr].to = pieceList[piece] = sq = toX + (toY<<4);
-    if(piece == pieceList[1] && fromY == toY && (toX > fromX+1 || toX < fromX-1) && fromX != BOARD_LEFT && fromX != BOARD_RGHT-1) {
+    if(piece == pieceList[1] && fromY == toY) {
+      if((toX > fromX+1 || toX < fromX-1) && fromX != BOARD_LEFT && fromX != BOARD_RGHT-1) {
        int from = toX>fromX ? BOARD_RGHT-1 : BOARD_LEFT;
        moveDatabase[movePtr++].piece = Q_WCASTL;
        quickBoard[sq] = piece;
        piece = quickBoard[from]; quickBoard[from] = 0;
        moveDatabase[movePtr].to = pieceList[piece] = sq = toX>fromX ? sq-1 : sq+1;
+      } else if((rook = quickBoard[sq]) && pieceType[rook] == WhiteRook) { // FRC castling
+       quickBoard[sq] = 0; // remove Rook
+       moveDatabase[movePtr].to = sq = (toX>fromX ? BOARD_RGHT-2 : BOARD_LEFT+2); // King to-square
+       moveDatabase[movePtr++].piece = Q_WCASTL;
+       quickBoard[sq] = pieceList[1]; // put King
+       piece = rook;
+       moveDatabase[movePtr].to = pieceList[rook] = sq = toX>fromX ? sq-1 : sq+1;
+      }
     } else
-    if(piece == pieceList[2] && fromY == toY && (toX > fromX+1 || toX < fromX-1) && fromX != BOARD_LEFT && fromX != BOARD_RGHT-1) {
+    if(piece == pieceList[2] && fromY == toY) {
+      if((toX > fromX+1 || toX < fromX-1) && fromX != BOARD_LEFT && fromX != BOARD_RGHT-1) {
        int from = (toX>fromX ? BOARD_RGHT-1 : BOARD_LEFT) + (BOARD_HEIGHT-1 <<4);
        moveDatabase[movePtr++].piece = Q_BCASTL;
        quickBoard[sq] = piece;
        piece = quickBoard[from]; quickBoard[from] = 0;
        moveDatabase[movePtr].to = pieceList[piece] = sq = toX>fromX ? sq-1 : sq+1;
+      } else if((rook = quickBoard[sq]) && pieceType[rook] == BlackRook) { // FRC castling
+       quickBoard[sq] = 0; // remove Rook
+       moveDatabase[movePtr].to = sq = (toX>fromX ? BOARD_RGHT-2 : BOARD_LEFT+2);
+       moveDatabase[movePtr++].piece = Q_BCASTL;
+       quickBoard[sq] = pieceList[2]; // put King
+       piece = rook;
+       moveDatabase[movePtr].to = pieceList[rook] = sq = toX>fromX ? sq-1 : sq+1;
+      }
     } else
     if(epOK && (pieceType[piece] == WhitePawn || pieceType[piece] == BlackPawn) && fromX != toX && quickBoard[sq] == 0) {
        quickBoard[(fromY<<4)+toX] = 0;
index 0597025..fb1ae4f 100644 (file)
--- a/backend.h
+++ b/backend.h
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
  *
 #ifndef XB_BACKEND
 #define XB_BACKEND
 
-/* unsigned int 64 for engine nodes work and display */
-#ifdef WIN32
-       /* I don't know the name for this type of other compiler
-        * If it not work, just modify here
-        * This is for MS Visual Studio
-        */
-       #ifdef _MSC_VER
-               #define u64 unsigned __int64
-               #define s64 signed __int64
-               #define u64Display "%I64u"
-               #define s64Display "%I64d"
-               #define u64Const(c) (c ## UI64)
-               #define s64Const(c) (c ## I64)
-       #else
-               /* place holder
-                * or dummy types for other compiler
-                * [HGM] seems that -mno-cygwin comple needs %I64?
-                */
-               #define u64 unsigned long long
-               #define s64 signed long long
-               #ifdef USE_I64
-                  #define u64Display "%I64u"
-                  #define s64Display "%I64d"
-               #else
-                  #define u64Display "%llu"
-                  #define s64Display "%lld"
-               #endif
-               #define u64Const(c) (c ## ULL)
-               #define s64Const(c) (c ## LL)
-       #endif
-#else
-       /* GNU gcc */
-       #define u64 unsigned long long
-       #define s64 signed long long
-       #define u64Display "%llu"
-       #define s64Display "%lld"
-       #define u64Const(c) (c ## ull)
-       #define s64Const(c) (c ## ll)
-#endif
-
 #include "lists.h"
 
 typedef int (*FileProc) P((FILE *f, int n, char *title));
index ed1675d..75e1b41 100644 (file)
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
  *
diff --git a/board.c b/board.c
index ab3985e..abd2a68 100644 (file)
--- a/board.c
+++ b/board.c
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * The following terms apply to Digital Equipment Corporation's copyright
  * interest in XBoard:
diff --git a/board.h b/board.h
index f6cca1e..852230c 100644 (file)
--- a/board.h
+++ b/board.h
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * The following terms apply to Digital Equipment Corporation's copyright
  * interest in XBoard:
diff --git a/book.c b/book.c
index 2bb542f..ec3f543 100644 (file)
--- a/book.c
+++ b/book.c
@@ -759,6 +759,9 @@ TextToMoves (char *text, int moveNum, entry_t *entries)
            text = strstr(text, yy_textstr) + strlen(yy_textstr); // skip what we parsed
            if(!valid || moveType != NormalMove && moveType != WhiteDrop && moveType != BlackDrop
                                                 && moveType != WhitePromotion && moveType != BlackPromotion
+                                                && moveType != WhiteCapturesEnPassant && moveType != BlackCapturesEnPassant
+                                                && moveType != WhiteKingSideCastle && moveType != BlackKingSideCastle
+                                                && moveType != WhiteQueenSideCastle && moveType != BlackQueenSideCastle
                                                 && moveType != WhiteNonPromotion && moveType != BlackNonPromotion) continue;
            if(*text == ' ' && sscanf(text+1, "{%hd/%hd}", &entries[count].learnPoints, &entries[count].learnCount) == 2) {
                text = strchr(text+1, '}') + 1;
index da1a452..0cbc460 100644 (file)
--- a/childio.c
+++ b/childio.c
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * The following terms apply to Digital Equipment Corporation's copyright
  * interest in XBoard:
index 0a1b494..402ddea 100644 (file)
--- a/childio.h
+++ b/childio.h
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * The following terms apply to Digital Equipment Corporation's copyright
  * interest in XBoard:
index 7ff69c5..698e53a 100644 (file)
--- a/cmail.in
+++ b/cmail.in
@@ -2,7 +2,7 @@
 ## (configure will change the top line to the location of perl on your system)
 #=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=#
 ## cmail: a tool to aid playing chess by email
-## Copyright (C) 1993,2009, 2010, 2011, 2012, 2013  Free Software Foundation, Inc.
+## Copyright (C) 1993,2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
 ## 
 ##  cmail is free software: you can redistribute it and/or modify
 ##  it under the terms of the GNU General Public License as published by
index 9cb0cd9..f8a521a 100644 (file)
--- a/dialogs.c
+++ b/dialogs.c
@@ -1,7 +1,7 @@
 /*
  * dialogs.c -- platform-independent code for dialogs of XBoard
  *
- * Copyright 2000, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Copyright 2000, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  * ------------------------------------------------------------------------
  *
  * GNU XBoard is free software: you can redistribute it and/or modify
@@ -1416,7 +1416,7 @@ ShuffleOK (int n)
 }
 
 static Option shuffleOptions[] = {
-  {   0,  0,   50, NULL, (void*) &shuffleOpenings, NULL, NULL, CheckBox, N_("shuffle") },
+  {   0,  0,    0, NULL, (void*) &shuffleOpenings, NULL, NULL, CheckBox, N_("shuffle") },
   { 0,-1,2000000000, NULL, (void*) &appData.defaultFrcPosition, "", NULL, Spin, N_("Start-position number:") },
   {   0,  0,    0, NULL, (void*) &SetRandom, NULL, NULL, Button, N_("randomize") },
   {   0,  SAME_ROW,    0, NULL, (void*) &SetRandom, NULL, NULL, Button, N_("pick fixed") },
@@ -2543,13 +2543,17 @@ Refresh (int pathFlag)
     SetWidgetLabel(&browseOptions[0], title);
 }
 
+static char msg1[] = N_("FIRST TYPE DIRECTORY NAME HERE");
+static char msg2[] = N_("TRY ANOTHER NAME");
+
 void
 CreateDir (int n)
 {
     char *name, *errmsg = "";
     GetWidgetText(&browseOptions[n-1], &name);
-    if(!name[0]) errmsg = _("FIRST TYPE DIRECTORY NAME HERE"); else
-    if(mkdir(name, 0755)) errmsg = _("TRY ANOTHER NAME");
+    if(!strcmp(name, msg1) || !strcmp(name, msg2)) return;
+    if(!name[0]) errmsg = _(msg1); else
+    if(mkdir(name, 0755)) errmsg = _(msg2);
     else {
        chdir(name);
        Refresh(-1);
index 3329e76..ab51fef 100644 (file)
--- a/dialogs.h
+++ b/dialogs.h
@@ -1,7 +1,7 @@
 /*
  * dialogs.h -- shared variables for generic dialog popup of XBoard
  *
- * Copyright 2000, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Copyright 2000, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  * ------------------------------------------------------------------------
  *
  * GNU XBoard is free software: you can redistribute it and/or modify
index f1d25c5..5008433 100644 (file)
@@ -24,14 +24,14 @@ See script make-xboard-release that can handle GNU-upload and tagging in git.
   1) email gnu (check admin page for gnu) http://www.gnu.org/prep/maintain/html_node/Announcements.html#Announcements
   2) email chess servers (ICS, FICS) and other web directories
   3) email linux distributions/update opensuse (Arun can handle OpenSUSE)
-  4) email info-gnu-chess 
+  4) email info-gnu-chess
 - update freshmeat.net (Tim can do this, email him)
 - newsgroups add short discription of xboard to news item
   1)  gnu.chess, info-gnu-chess
   2)  rec.games.chess.computer
   3)  comp.os.linux.announce
-  4)  WinBoard forum web page (HGM does this one) 
-- update git to the next pre-release 
+  4)  WinBoard forum web page (HGM does this one)
+- update git to the next pre-release
 
 ** Template for emails
 
@@ -39,14 +39,14 @@ fill in the <...>
 
 Subject: release of XBoard version <...>
 
-Hello, 
+Hello,
 
 A new version of XBoard is available. Here are some details:
 
 Short description:
 
-XBoard is a graphical user interface for chess in all its major forms, 
-including international chess, xiangqi (Chinese chess), shogi Japanese chess) 
+XBoard is a graphical user interface for chess in all its major forms,
+including international chess, xiangqi (Chinese chess), shogi Japanese chess)
 and Makruk. Many variations of chess are also supported.
 
 Web page:
@@ -59,13 +59,13 @@ http://ftp.gnu.org/gnu/xboard/
 
 Windows binaries will be available at:
 
-http://www.open-aurec.com/wbforum/viewforum.php?f=19 
+http://www.open-aurec.com/wbforum/viewforum.php?f=19
 
 Development at:
 
 https://savannah.gnu.org/projects/xboard/
 
-News: 
+News:
 
 <list of most important new features>
 See the NEWS file in the distribution or git for more details.
diff --git a/draw.c b/draw.c
index 783f240..f89468d 100644 (file)
--- a/draw.c
+++ b/draw.c
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * The following terms apply to Digital Equipment Corporation's copyright
  * interest in XBoard:
diff --git a/draw.h b/draw.h
index b666150..cf6ceab 100644 (file)
--- a/draw.h
+++ b/draw.h
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * The following terms apply to Digital Equipment Corporation's copyright
  * interest in XBoard:
index 42eccc0..e22df5e 100644 (file)
@@ -5,7 +5,7 @@
  *
  * Copyright 2005 Alessandro Scotti
  *
- * Enhancements Copyright 1995, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Enhancements Copyright 1995, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * ------------------------------------------------------------------------
  *
@@ -413,7 +413,7 @@ InsertionPoint (int len, EngineOutputData *ed)
                if(ed->moveKey != keys[i+n] && // same move always tops previous one (as a higher score must be a fail low)
                   newScore < scores[i+n]) break;
                // if it had higher score as previous, move previous in stead
-               scores[i+n+2] = scores[i+n];
+               scores[i+n+2] = ed->moveKey == keys[i+n] ? newScore : scores[i+n]; // correct scores of fail-low/high searches
                textEnd[i+n+2] = textEnd[i+n] + len;
                keys[i+n+2] = keys[i+n];
        }
index 098f6a8..23127aa 100644 (file)
@@ -1,7 +1,7 @@
 /*
  * wengineo.h -- Clipboard routines for WinBoard
  *
- * Copyright 2000, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Copyright 2000, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
  *
index 2da07fd..2767560 100644 (file)
@@ -5,7 +5,7 @@
  *
  * Copyright 2005 Alessandro Scotti
  *
- * Enhancments Copyright 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Enhancments Copyright 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * ------------------------------------------------------------------------
  *
index 2e05db6..9d3ae7d 100644 (file)
@@ -1,7 +1,7 @@
 /*
  * evalgraph.h -- Evaluation Graph window
  *
- * Copyright 2000, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Copyright 2000, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
  *
index d16fde6..6dcc1f7 100644 (file)
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
  *
@@ -216,7 +216,7 @@ void EnableNamedMenuItem P((char *menuRef, int state));
 typedef struct FrontEndProgramStats_TAG {
     int which;
     int depth;
-    unsigned long nodes;
+    u64 nodes;
     int score;
     int time;
     char * pv;
index a96aeca..62b4e83 100644 (file)
@@ -1,7 +1,7 @@
 /*
  * gamelist.c -- Functions to manage a gamelist
  *
- * Copyright 1995, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Copyright 1995, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
  *
index 0546a3a..750e64f 100644 (file)
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * The following terms apply to Digital Equipment Corporation's copyright
  * interest in XBoard:
@@ -167,8 +167,8 @@ extern char *getenv();
 #include "gettext.h"
 #include "draw.h"
 
-#ifdef OSX
-#  include "gtkmacintegration/gtkosxapplication.h"
+#ifdef __APPLE__
+#  include <gtkmacintegration/gtkosxapplication.h>
    // prevent pathname of positional file argument provided by OS X being be mistaken for option name
    // (price is that we won't recognize Windows option format anymore).
 #  define SLASH '-'
@@ -182,6 +182,7 @@ extern char *getenv();
    char *dataDir; // for expanding ~~
 #else
 #  define SLASH '/'
+#  define DATADIR "~~"
 #endif
 
 #ifdef __EMX__
@@ -729,7 +730,7 @@ SlaveResize (Option *opt)
   gtk_window_resize(GTK_WINDOW(shells[DummyDlg]), slaveW + opt->max, slaveH + opt->value);
 }
 
-#ifdef OSX
+#ifdef __APPLE__
 static char clickedFile[MSG_SIZ];
 static int suppress;
 
@@ -773,7 +774,7 @@ main (int argc, char **argv)
 
     /* set up GTK */
     gtk_init (&argc, &argv);
-#ifdef OSX
+#ifdef __APPLE__
     {   // prepare to catch OX OpenFile signal, which will tell us the clicked file
        GtkosxApplication *theApp = g_object_new(GTKOSX_TYPE_APPLICATION, NULL);
        dataDir = gtkosx_application_get_bundle_path();
@@ -1786,7 +1787,7 @@ TempForwardProc (Widget w, XEvent *event, String *prms, Cardinal *nprms)
 void
 ManProc ()
 {   // called from menu
-#ifdef OSX
+#ifdef __APPLE__
     system("%s ./man.command", appData.sysOpen);
 #else
     system("xterm -e man xboard &");
index 5326af8..7a7d36f 100644 (file)
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * The following terms apply to Digital Equipment Corporation's copyright
  * interest in XBoard:
index ceda49e..74ae0e6 100644 (file)
@@ -5,7 +5,7 @@
  *
  * Copyright 2005 Alessandro Scotti
  *
- * Enhancements Copyright 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Enhancements Copyright 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * ------------------------------------------------------------------------
  *
index c8bbd07..b618013 100644 (file)
@@ -1,7 +1,7 @@
 /*
  * xoptions.c -- Move list window, part of X front end for XBoard
  *
- * Copyright 2000, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Copyright 2000, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  * ------------------------------------------------------------------------
  *
  * GNU XBoard is free software: you can redistribute it and/or modify
@@ -51,8 +51,8 @@ extern char *getenv();
 #include <cairo/cairo-xlib.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-#ifdef OSX
-#  include "gtkmacintegration/gtkosxapplication.h"
+#ifdef __APPLE__
+#  include <gtkmacintegration/gtkosxapplication.h>
 #endif
 
 #include "common.h"
@@ -428,7 +428,7 @@ CreateMenuPopup (Option *opt, int n, int def)
       {
        char *msg = mb[i].string;
        if(!msg) break;
-#ifdef OSX
+#ifdef __APPLE__
        if(!strcmp(msg, "Quit ")) continue;             // Quit item will appear automatically in App menu
        if(!strcmp(msg, "About XBoard")) msg = "About"; // 'XBoard' will be appended automatically when moved to App menu 1st item
 #endif
@@ -445,11 +445,11 @@ CreateMenuPopup (Option *opt, int n, int def)
            GdkModifierType accelerator_mods;
 
            gtk_accelerator_parse(mb[i].accel, &accelerator_key, &accelerator_mods);
-#ifdef OSX
+#ifdef __APPLE__
            if(accelerator_mods & GDK_CONTROL_MASK) {  // in OSX use Meta where Linux uses Ctrl
                accelerator_mods &= ~GDK_CONTROL_MASK; // clear Ctrl flag
                accelerator_mods |= GDK_META_MASK;     // set Meta flag
-           } 
+           }
 #endif
            gtk_widget_add_accelerator (GTK_WIDGET(entry), "activate",GtkAccelerators,
                                        accelerator_key, accelerator_mods, GTK_ACCEL_VISIBLE);
@@ -1498,7 +1498,7 @@ if(appData.debugMode) printf("n=%d, h=%d, w=%d\n",n,height,width);
            break;
          case BarEnd:
            top--;
-#ifndef OSX
+#ifndef __APPLE__
             gtk_table_attach(GTK_TABLE(table), menuBar, left, left+r, top, top+1, GTK_FILL | GTK_EXPAND, GTK_FILL, 2, 1);
 
            if(option[i].target) ((ButtonCallback*)option[i].target)(boxStart); // callback that can make sizing decisions
@@ -1511,7 +1511,7 @@ if(appData.debugMode) printf("n=%d, h=%d, w=%d\n",n,height,width);
                gtkosx_application_set_menu_bar(theApp, GTK_MENU_SHELL(menuBar));
                gtkosx_application_insert_app_menu_item(theApp, GTK_MENU_ITEM(helpMenu[8].handle), 0); // hack
                gtkosx_application_sync_menubar(theApp);
-           } 
+           }
 #endif
            break;
          case BoxEnd:
index 7f17c92..7ec2320 100644 (file)
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * The following terms apply to Digital Equipment Corporation's copyright
  * interest in XBoard:
index ef9a936..ca87aa4 100644 (file)
--- a/history.c
+++ b/history.c
@@ -6,7 +6,7 @@
  *
  * Copyright 2005 Alessandro Scotti
  *
- * Enhancements Copyright 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Enhancements Copyright 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * ------------------------------------------------------------------------
  *
diff --git a/lists.c b/lists.c
index 2d09beb..779606e 100644 (file)
--- a/lists.c
+++ b/lists.c
@@ -1,7 +1,7 @@
 /*
  * lists.c -- Functions to implement a double linked list XBoard
  *
- * Copyright 1995, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Copyright 1995, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
  *
diff --git a/lists.h b/lists.h
index 849a903..36b138b 100644 (file)
--- a/lists.h
+++ b/lists.h
@@ -1,7 +1,7 @@
 /*
  * lists.c -- Includefile of lists.c
  *
- * Copyright 1995, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Copyright 1995, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
  *
diff --git a/menus.c b/menus.c
index 03829b9..11fe7a9 100644 (file)
--- a/menus.c
+++ b/menus.c
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * The following terms apply to Digital Equipment Corporation's copyright
  * interest in XBoard:
diff --git a/menus.h b/menus.h
index 7d810d4..be62d47 100644 (file)
--- a/menus.h
+++ b/menus.h
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * The following terms apply to Digital Equipment Corporation's copyright
  * interest in XBoard:
diff --git a/moves.c b/moves.c
index 52b609c..7ffe59d 100644 (file)
--- a/moves.c
+++ b/moves.c
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
  *
@@ -1224,6 +1224,7 @@ GenLegal (Board board, int  flags, MoveCallback callback, VOIDSTAR closure, Ches
             if(ff <= BOARD_LEFT+2) { left = ff+1; right = BOARD_LEFT+3; }
             for(k=left; k<=right && ft != NoRights; k++) /* first test if blocked */
                 if(k != ft && board[0][k] != EmptySquare) ft = NoRights;
+            if(ft == 0 && ff != 1 && board[0][1] != EmptySquare) ft = NoRights; /* Rook can be blocked on b1 */
             if(ff > BOARD_LEFT+2)
             for(k=left+1; k<=right && ft != NoRights; k++) /* then if not checked */
                 if(!ignoreCheck && CheckTest(board, flags, 0, ff, 0, k, FALSE)) ft = NoRights;
@@ -1250,6 +1251,7 @@ GenLegal (Board board, int  flags, MoveCallback callback, VOIDSTAR closure, Ches
             if(ff <= BOARD_LEFT+2) { left = ff+1; right = BOARD_LEFT+3; }
             for(k=left; k<=right && ft != NoRights; k++) /* first test if blocked */
                 if(k != ft && board[BOARD_HEIGHT-1][k] != EmptySquare) ft = NoRights;
+            if(ft == 0 && ff != 1 && board[BOARD_HEIGHT-1][1] != EmptySquare) ft = NoRights; /* Rook can be blocked on b8 */
             if(ff > BOARD_LEFT+2)
             for(k=left+1; k<=right && ft != NoRights; k++) /* then if not checked */
                 if(!ignoreCheck && CheckTest(board, flags, BOARD_HEIGHT-1, ff, BOARD_HEIGHT-1, k, FALSE)) ft = NoRights;
diff --git a/moves.h b/moves.h
index bef3073..b4b9eb3 100644 (file)
--- a/moves.h
+++ b/moves.h
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
  *
index 30ee4cf..ce77057 100644 (file)
@@ -5,7 +5,7 @@
  *
  * Copyright 2005 Alessandro Scotti
  *
- * Enhancements Copyright 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Enhancements Copyright 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * ------------------------------------------------------------------------
  *
index d7b9923..d904806 100644 (file)
@@ -6,7 +6,7 @@
  *
  * Copyright 2005 Alessandro Scotti
  *
- * Enhancements Copyright 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Enhancements Copyright 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * ------------------------------------------------------------------------
  *
index 0d466f5..c843d38 100644 (file)
@@ -1,7 +1,7 @@
 /*
  * ngamelist.c -- Game list window, Xt-independent front-end code for XBoard
  *
- * Copyright 1995, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Copyright 1995, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  * ------------------------------------------------------------------------
  *
  * GNU XBoard is free software: you can redistribute it and/or modify
index eef26cf..9cf56c0 100644 (file)
@@ -1,7 +1,7 @@
 /*
  * New (WinBoard-style) Move history for XBoard
  *
- * Copyright 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  * ------------------------------------------------------------------------
  *
  * GNU XBoard is free software: you can redistribute it and/or modify
index 08dc513..481e7b2 100644 (file)
--- a/parser.c
+++ b/parser.c
@@ -1,7 +1,7 @@
 /*
  * parser.c --
  *
- * Copyright 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Copyright 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  * ------------------------------------------------------------------------
  *
  * GNU XBoard is free software: you can redistribute it and/or modify
@@ -174,6 +174,10 @@ NextUnit (char **p)
            if(fromString) return 0; // we are parsing string, so the end is really the end
            *p = inPtr = inputBuf;
            if(!ReadLine()) return 0; // EOF
+       } else if(inPtr > inputBuf + PARSEBUFSIZE/2) { // buffer fills up with already parsed stuff
+           char *q = *p, *r = inputBuf;
+           while(*r++ = *q++);
+           *p = inputBuf; inPtr = r - 1;
        }
        parseStart = oldp = *p; // remember where we begin
 
index 69c17cb..f21fdb4 100644 (file)
--- a/parser.h
+++ b/parser.h
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
  *
index 8b55af6..74e4495 100644 (file)
--- a/pgntags.c
+++ b/pgntags.c
@@ -1,7 +1,7 @@
 /*
  * pgntags.c -- Functions to manage PGN tags
  *
- * Copyright 1995, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Copyright 1995, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
  *
index 0413b62..1bdb134 100755 (executable)
@@ -2,7 +2,7 @@
 #  lng2po.sh -- translating .lng files to .po files for XBoard/Winboard,
 #               part of XBoard GNU project
 #
-#  Copyright 2011, 2013 Free Software Foundation, Inc.
+#  Copyright 2011, 2013, 2014 Free Software Foundation, Inc.
 #  ------------------------------------------------------------------------
 #
 #  GNU XBoard is free software: you can redistribute it and/or modify
index 7fb7281..2cc7e05 100644 (file)
--- a/po/ru.po
+++ b/po/ru.po
@@ -13,10 +13,10 @@ msgstr ""
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: LANGUAGE <LL@li.org>\n"
-"Language: ru\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
+"Language: ru\n"
 
 #: args.h:821
 #, c-format
diff --git a/themes/xiangqi/.DS_Store b/themes/xiangqi/.DS_Store
deleted file mode 100644 (file)
index 5008ddf..0000000
Binary files a/themes/xiangqi/.DS_Store and /dev/null differ
diff --git a/uci.c b/uci.c
index 4a6c177..a2e5607 100644 (file)
--- a/uci.c
+++ b/uci.c
@@ -5,7 +5,7 @@
  *
  * Copyright 2006 Alessandro Scotti
  *
- * Enhancement Copyright 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Enhancement Copyright 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * ------------------------------------------------------------------------
  *
index 31a0cda..eb006b1 100644 (file)
--- a/usounds.c
+++ b/usounds.c
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * The following terms apply to Digital Equipment Corporation's copyright
  * interest in XBoard:
index a051523..2334572 100644 (file)
--- a/usystem.c
+++ b/usystem.c
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * The following terms apply to Digital Equipment Corporation's copyright
  * interest in XBoard:
index b1ddd48..b776652 100644 (file)
--- a/usystem.h
+++ b/usystem.h
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * The following terms apply to Digital Equipment Corporation's copyright
  * interest in XBoard:
index fcab2db..0d04e0f 100644 (file)
@@ -5,7 +5,7 @@
  * Massachusetts.\r
  *\r
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,\r
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.\r
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.\r
  *\r
  * Enhancements Copyright 2005 Alessandro Scotti\r
  *\r
index f76e299..7fff5a0 100644 (file)
@@ -1,7 +1,7 @@
 /*\r
  * help.h\r
  *\r
- * Copyright 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.\r
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.\r
  * ------------------------------------------------------------------------\r
  *\r
  * GNU XBoard is free software: you can redistribute it and/or modify\r
index 6816562..9a747df 100644 (file)
@@ -12,7 +12,7 @@
 <P><B><A NAME="copyright"></A>COPYRIGHT</B></P>\r
 \r
 <P>Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts. <BR>\r
-Enhancements Copyright 1992-2013 Free Software Foundation, Inc.</P>\r
+Enhancements Copyright 1992-2014 Free Software Foundation, Inc.</P>\r
 \r
 <P>The following terms apply to Digital Equipment Corporation's copyright interest in WinBoard:</P>\r
 \r
index f488039..b5961cb 100644 (file)
@@ -5,7 +5,7 @@
  * Massachusetts.\r
  *\r
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,\r
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.\r
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.\r
  *\r
  * XBoard borrows its colors and the bitmaps.xchess bitmap set from XChess,\r
  * which was written and is copyrighted by Wayne Christopher.\r
index 216dcaf..4c8d940 100644 (file)
@@ -196,7 +196,7 @@ ABOUTBOX
 "OK" === ""\r
 "Chessboard for Windows" === ""\r
 "Copyright 1991 Digital Equipment Corporation" === ""\r
-"Enhancements Copyright 1992-2013  Free Software Foundation" === ""\r
+"Enhancements Copyright 1992-2014  Free Software Foundation" === ""\r
 "Enhancements Copyright 2005\r\nAlessandro Scotti" === ""\r
 ## What happened with H.G.Muller? [He sold his copyrights to FSF for $1]\r
 ## The following string of 6 spaces can be translated to an acknowledgement of the translator,\r
index e4ee588..808482e 100644 (file)
@@ -164,7 +164,7 @@ ABOUTBOX
 "OK" === "OK"\r
 "Chessboard for Windows" === "Schachbrett für Windows"\r
 "Copyright 1991 Digital Equipment Corporation" === "Copyright (c) Digital Equipment Corporation 1991"\r
-"Enhancements Copyright 1992-2013  Free Software Foundation" === "Weiter Copyright (c) Free Software Fundation 1992-2010"\r
+"Enhancements Copyright 1992-2014  Free Software Foundation" === "Weiter Copyright (c) Free Software Fundation 1992-2014"\r
 "Enhancements Copyright 2005\r\nAlessandro Scotti" === "Weiter Copyright (c) \r\nAlessandro Scotti 2005"\r
 "WinBoard 0.0.0" === "WinBoard 0.0.0"\r
 \r
index 2e43e76..f1f3925 100644 (file)
@@ -198,7 +198,7 @@ ABOUTBOX
 "OK" === "OK"\r
 "Chessboard for Windows" === "Interfaccia per gli Scacchi e varianti per Windows"\r
 "Copyright 1991 Digital Equipment Corporation" === "Copyright (C) 1991 Digital Equipment Corporation"\r
-"Enhancements Copyright 1992-2013  Free Software Foundation" === "Modifiche Copyright (C) 1992-2013 Free Software Foundation"\r
+"Enhancements Copyright 1992-2014  Free Software Foundation" === "Modifiche Copyright (C) 1992-2014 Free Software Foundation"\r
 "Enhancements Copyright 2005\r\nAlessandro Scotti" === "Modifiche Copyright (C) 2005\r\nAlessandro Scotti"\r
 ## What happened with H.G.Muller? [He sold his copyrights to FSF for $1]\r
 ## The following string of 6 spaces can be translated to an acknowledgement of the translator,\r
index 2947206..3ac85fc 100644 (file)
@@ -172,7 +172,7 @@ ABOUTBOX
 "OK" === "OK"\r
 "Chessboard for Windows" === "Schaakbord voor Windows"\r
 "Copyright 1991 Digital Equipment Corporation" === ""\r
-"Enhancements Copyright 1992-2013  Free Software Foundation" === ""\r
+"Enhancements Copyright 1992-2014  Free Software Foundation" === ""\r
 "Enhancements Copyright 2005\r\nAlessandro Scotti" === ""\r
 ## What happened with H.G.Muller? [He sold his copyrights to FSF for $1]\r
 ## The following string of 6 spaces can be translated to an acknowledgement of the translator,\r
index 01164d8..8559006 100644 (file)
@@ -184,7 +184,7 @@ ABOUTBOX
 "OK" === "OK"\r
 "Chessboard for Windows" === "WinBoard GUI pentru Windows"\r
 "Copyright 1991 Digital Equipment Corporation" === ""\r
-"Enhancements Copyright 1992-2013  Free Software Foundation" === ""\r
+"Enhancements Copyright 1992-2014  Free Software Foundation" === ""\r
 "Enhancements Copyright 2005\r\nAlessandro Scotti" === ""\r
 ## What happened with H.G.Muller? [He sold his copyrights to FSF for $1]\r
 ## The following string of 6 spaces can be translated to an acknowledgement of the translator,\r
index e8b95eb..ae11cf4 100644 (file)
@@ -197,7 +197,7 @@ ABOUTBOX
 "OK" === "OK"\r
 "Chessboard for Windows" === "Øàõìàòíàÿ äîñêà äëÿ Windows"\r
 "Copyright 1991 Digital Equipment Corporation" === ""\r
-"Enhancements Copyright 1992-2013  Free Software Foundation" === ""\r
+"Enhancements Copyright 1992-2014  Free Software Foundation" === ""\r
 "Enhancements Copyright 2005\r\nAlessandro Scotti" === ""\r
 ## What happened with H.G.Muller? [He sold his copyrights to FSF for $1]\r
 ## The following string of 6 spaces can be translated to an acknowledgement of the translator,\r
index fa7f79b..a1ada60 100644 (file)
@@ -172,7 +172,7 @@ ABOUTBOX
 "Chessboard for Windows" === "Tablero de ajedrez para Windows"\r
 ## Following 3 strings doesn't get translated :(\r
 "Copyright 1991 Digital Equipment Corporation" === "(c) Copyright Digital Equipment Corporation 1991"\r
-"Enhancements Copyright 1992-2013  Free Software Foundation" === "Mejoras (c) Copyright Free Software Fundation 1992-2010"\r
+"Enhancements Copyright 1992-2014  Free Software Foundation" === "Mejoras (c) Copyright Free Software Fundation 1992-2010"\r
 "Enhancements Copyright 2005\r\nAlessandro Scotti" === "Mejoras (c) Copyright\r\nAlessandro Scotti 2005"\r
 ## What happened with H.G.Muller?\r
 ## Absolutely needed a link to download the most recent version\r
index bb7c602..ca4e312 100644 (file)
@@ -196,7 +196,7 @@ ABOUTBOX
 "OK" === "Ðýõòc"\r
 "Chessboard for Windows" === "Bàn CõÌ Cho Windows"\r
 "Copyright 1991 Digital Equipment Corporation" === "BaÒn QuyêÌn 1991 Digital Equipment Corporation"\r
-"Enhancements Copyright 1992-2013  Free Software Foundation" === ""\r
+"Enhancements Copyright 1992-2014  Free Software Foundation" === ""\r
 "Enhancements Copyright 2005\r\nAlessandro Scotti" === ""\r
 ## What happened with H.G.Muller? [He sold his copyrights to FSF for $1]\r
 ## The following string of 6 spaces can be translated to an acknowledgement of the translator,\r
index e06d996..6346c7d 100644 (file)
@@ -3,7 +3,7 @@
  *\r
  * Author: H.G.Muller (August 2009)\r
  *\r
- * Copyright 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.\r
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.\r
  *\r
  * ------------------------------------------------------------------------\r
  *\r
index 08a97bf..e46647d 100644 (file)
@@ -1,7 +1,7 @@
 /*\r
  * wclipbrd.c -- Clipboard routines for WinBoard\r
  *\r
- * Copyright 2000, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.\r
+ * Copyright 2000, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.\r
  *\r
  * Enhancements Copyright 2005 Alessandro Scotti\r
  *\r
index 16992f0..53149ed 100644 (file)
@@ -1,7 +1,7 @@
 /*\r
  * wclipbrd.c -- Clipboard routines for WinBoard\r
  *\r
- * Copyright 2000, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.\r
+ * Copyright 2000, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.\r
  *\r
  * Enhancements Copyright 2005 Alessandro Scotti\r
  *\r
index bd34038..b3cf334 100644 (file)
@@ -1,7 +1,7 @@
 /*\r
  * wedittags.c -- EditTags window for WinBoard\r
  *\r
- * Copyright 1995, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.\r
+ * Copyright 1995, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.\r
  *\r
  * Enhancements Copyright 2005 Alessandro Scotti\r
  *\r
index 47bca87..d3a673f 100644 (file)
@@ -5,7 +5,7 @@
  *\r
  * Copyright 2005 Alessandro Scotti\r
  *\r
- * Enhancements Copyright 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.\r
+ * Enhancements Copyright 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.\r
  *\r
  * ------------------------------------------------------------------------\r
  *\r
index 5a6ca62..ee71b60 100644 (file)
@@ -5,6 +5,8 @@
  *\r
  * Copyright 2005 Alessandro Scotti\r
  *\r
+ * Enhancements Copyright 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.\r
+ *\r
  * ------------------------------------------------------------------------\r
  *\r
  * GNU XBoard is free software: you can redistribute it and/or modify\r
index 2512bc8..4fa6025 100644 (file)
@@ -1,7 +1,7 @@
 /*\r
  * wgamelist.c -- Game list window for WinBoard\r
  *\r
- * Copyright 1995, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.\r
+ * Copyright 1995, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.\r
  *\r
  * Enhancements Copyright 2005 Alessandro Scotti\r
  *\r
index 96a08e2..d0d897a 100644 (file)
@@ -6,6 +6,8 @@
  *\r
  * Copyright 2005 Alessandro Scotti\r
  *\r
+ * Enhancements Copyright 2009, 2010, 2014 Free Software Foundation, Inc.\r
+ *\r
  * ------------------------------------------------------------------------\r
  *\r
  * GNU XBoard is free software: you can redistribute it and/or modify\r
@@ -19,7 +21,7 @@
  * General Public License for more details.\r
  *\r
  * You should have received a copy of the GNU General Public License\r
- * along with this program. If not, see http://www.gnu.org/licenses/. \r
+ * along with this program. If not, see http://www.gnu.org/licenses/.\r
  *\r
  * ------------------------------------------------------------------------\r
  ** See the file ChangeLog for a revision history.  */\r
index 917a532..1b8460b 100644 (file)
@@ -2,10 +2,10 @@
  * WinBoard.c -- Windows NT front end to XBoard\r
  *\r
  * Copyright 1991 by Digital Equipment Corporation, Maynard,\r
- * Massachusetts. \r
+ * Massachusetts.\r
  *\r
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,\r
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.\r
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.\r
  *\r
  * Enhancements Copyright 2005 Alessandro Scotti\r
  *\r
@@ -984,16 +984,17 @@ InitApplication(HINSTANCE hInstance)
 \r
 /* Set by InitInstance, used by EnsureOnScreen */\r
 int screenHeight, screenWidth;\r
+RECT screenGeometry;\r
 \r
 void\r
 EnsureOnScreen(int *x, int *y, int minX, int minY)\r
 {\r
 //  int gap = GetSystemMetrics(SM_CYFRAME) + GetSystemMetrics(SM_CYCAPTION);\r
   /* Be sure window at (x,y) is not off screen (or even mostly off screen) */\r
-  if (*x > screenWidth - 32) *x = 0;\r
-  if (*y > screenHeight - 32) *y = 0;\r
-  if (*x < minX) *x = minX;\r
-  if (*y < minY) *y = minY;\r
+  if (*x > screenGeometry.right - 32) *x = screenGeometry.left;\r
+  if (*y > screenGeometry.bottom - 32) *y = screenGeometry.top;\r
+  if (*x < screenGeometry.left + minX) *x = screenGeometry.left + minX;\r
+  if (*y < screenGeometry.top + minY) *y = screenGeometry.top + minY;\r
 }\r
 \r
 VOID\r
@@ -1054,6 +1055,32 @@ InitTextures()
   }\r
 }\r
 \r
+#ifndef SM_CXVIRTUALSCREEN\r
+#define SM_CXVIRTUALSCREEN 78\r
+#endif\r
+#ifndef SM_CYVIRTUALSCREEN\r
+#define SM_CYVIRTUALSCREEN 79\r
+#endif\r
+#ifndef SM_XVIRTUALSCREEN \r
+#define SM_XVIRTUALSCREEN 76\r
+#endif\r
+#ifndef SM_YVIRTUALSCREEN \r
+#define SM_YVIRTUALSCREEN 77\r
+#endif\r
+\r
+VOID\r
+InitGeometry()\r
+{\r
+  screenHeight = GetSystemMetrics(SM_CYVIRTUALSCREEN);\r
+  if( !screenHeight ) screenHeight = GetSystemMetrics(SM_CYSCREEN);\r
+  screenWidth = GetSystemMetrics(SM_CXVIRTUALSCREEN);\r
+  if( !screenWidth ) screenWidth = GetSystemMetrics(SM_CXSCREEN);\r
+  screenGeometry.left = GetSystemMetrics(SM_XVIRTUALSCREEN);\r
+  screenGeometry.top = GetSystemMetrics(SM_YVIRTUALSCREEN);\r
+  screenGeometry.right = screenGeometry.left + screenWidth;\r
+  screenGeometry.bottom = screenGeometry.top + screenHeight;\r
+}\r
+\r
 BOOL\r
 InitInstance(HINSTANCE hInstance, int nCmdShow, LPSTR lpCmdLine)\r
 {\r
@@ -1072,7 +1099,7 @@ InitInstance(HINSTANCE hInstance, int nCmdShow, LPSTR lpCmdLine)
     GetCurrentDirectory(MSG_SIZ, installDir);\r
   }\r
   gameInfo.boardWidth = gameInfo.boardHeight = 8; // [HGM] won't have open window otherwise\r
-  screenWidth = screenHeight = 1000; // [HGM] placement: kludge to allow calling EnsureOnScreen from InitAppData\r
+  InitGeometry();\r
   InitAppData(lpCmdLine);      /* Get run-time parameters */\r
   /* xboard, and older WinBoards, controlled the move sound with the\r
      appData.ringBellAfterMoves option.  In the current WinBoard, we\r
@@ -1119,8 +1146,7 @@ InitInstance(HINSTANCE hInstance, int nCmdShow, LPSTR lpCmdLine)
   iconBlack = LoadIcon(hInstance, "icon_black");\r
   iconCurrent = iconWhite;\r
   InitDrawingColors();\r
-  screenHeight = GetSystemMetrics(SM_CYSCREEN);\r
-  screenWidth = GetSystemMetrics(SM_CXSCREEN);\r
+\r
   InitPosition(0); // to set nr of ranks and files, which might be non-default through command-line args\r
   for (ibs = (int) NUM_SIZES - 1; ibs >= 0; ibs--) {\r
     /* Compute window size for each board size, and use the largest\r
index b3eee24..0998c97 100644 (file)
@@ -2,10 +2,10 @@
  * WinBoard.h -- Definitions for Windows NT front end to XBoard\r
  *\r
  * Copyright 1991 by Digital Equipment Corporation, Maynard,\r
- * Massachusetts. \r
+ * Massachusetts.\r
  *\r
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,\r
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.\r
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.\r
  *\r
  * Enhancements Copyright 2005 Alessandro Scotti\r
  *\r
@@ -194,7 +194,7 @@ typedef enum {
 extern WindowPlacement placementTab[NUM_WINDOWS];\r
 extern HWND hwndTab[NUM_WINDOWS]; // this remains pure front-end.\r
 \r
-void Translate( HWND hDlg, int id);
+void Translate( HWND hDlg, int id);\r
 VOID InitWindowPlacement( WindowPlacement * wp );\r
 VOID RestoreWindowPlacement( HWND hWnd, WindowPlacement * wp );\r
 VOID ReattachAfterMove( LPRECT lprcOldPos, int new_x, int new_y, HWND hWndChild, WindowPlacement * pwpChild );\r
@@ -216,4 +216,6 @@ extern HWND gameListDialog;
 \r
 VOID EditTagsProc(void);\r
 extern HWND editTagsDialog;\r
-extern int screenWidth, screenHeight;
+extern int screenWidth, screenHeight;\r
+extern RECT screenGeometry; // Top-left coordiate of the screen can be different from (0,0)\r
+\r
index 69ed9da..334a624 100644 (file)
@@ -44,7 +44,7 @@ BEGIN
     LTEXT           "Chessboard for Windows",400,25,15,121,8\r
     LTEXT           "Copyright 1991 Digital Equipment Corporation",201,6,34,\r
                     149,8\r
-    LTEXT           "Enhancements Copyright 1992-2013  Free Software Foundation",\r
+    LTEXT           "Enhancements Copyright 1992-2014  Free Software Foundation",\r
                     OPT_TCtext1,6,45,121,17\r
     CONTROL         "",OPT_TCTime,"Static",SS_BLACKRECT,4,28,159,1\r
     LTEXT           "WinBoard 0.0.0",ABOUTBOX_Version,25,5,160,8\r
@@ -248,7 +248,7 @@ BEGIN
     RTEXT           "Chessboard for Windows",IDC_ChessBoard,196,154,80,8\r
     LTEXT           "Copyright 1991 Digital Equipment Corporation",201,4,168,\r
                     151,8\r
-    LTEXT           "Enhancements Copyright 1992-2013   Free Software Foundation",\r
+    LTEXT           "Enhancements Copyright 1992-2014   Free Software Foundation",\r
                     OPT_TCtext1,4,179,126,17\r
     CONTROL         "",OPT_TCTime,"Static",SS_BLACKRECT,4,164,272,1\r
     LTEXT           "WinBoard 0.0.0",ABOUTBOX_Version,4,154,64,8\r
index 08f461f..bda1cfe 100644 (file)
@@ -5,6 +5,8 @@
  *\r
  * Copyright 2005 Alessandro Scotti\r
  *\r
+ * Enhancements Copyright 2009, 2012, 2013, 2014 Free Software Foundation, Inc.\r
+ *\r
  * ------------------------------------------------------------------------\r
  *\r
  * GNU XBoard is free software: you can redistribute it and/or modify\r
@@ -173,15 +175,15 @@ VOID ReattachAfterSize( LPRECT lprcOldPos, int new_w, int new_h, HWND hWndChild,
 \r
             /* Adjust size & placement */\r
             if(pwpChild->x + pwpChild->width  >= lprcOldPos->right &&\r
-              (pwpChild->x + pwpChild->width  < screenWidth - 5 || delta_x > 0) ) // keep right edge glued to display edge if touching\r
+              (pwpChild->x + pwpChild->width  < screenGeometry.right - 5 || delta_x > 0) ) // keep right edge glued to display edge if touching\r
                pwpChild->width += delta_x;\r
-            if(pwpChild->x + pwpChild->width  >= screenWidth  ) // don't move right edge off screen\r
-               pwpChild->width = screenWidth - pwpChild->x;\r
+            if(pwpChild->x + pwpChild->width  >= screenGeometry.right  ) // don't move right edge off screen\r
+               pwpChild->width = screenGeometry.right - pwpChild->x;\r
             if(pwpChild->y + pwpChild->height >= lprcOldPos->bottom &&\r
-              (pwpChild->y + pwpChild->height < screenHeight - 35 || delta_y > 0) ) // keep bottom edge glued to display edge if touching\r
+              (pwpChild->y + pwpChild->height < screenGeometry.bottom - 35 || delta_y > 0) ) // keep bottom edge glued to display edge if touching\r
                pwpChild->height += delta_y;\r
-            if(pwpChild->y + pwpChild->height >= screenHeight - 30 ) // don't move bottom edge off screen\r
-               pwpChild->height = screenHeight - 30 - pwpChild->y;\r
+            if(pwpChild->y + pwpChild->height >= screenGeometry.bottom - 30 ) // don't move bottom edge off screen\r
+               pwpChild->height = screenGeometry.bottom - 30 - pwpChild->y;\r
             if(pwpChild->x >= lprcOldPos->right)  pwpChild->width  -= delta_x, pwpChild->x += delta_x;\r
             if(pwpChild->y >= lprcOldPos->bottom) pwpChild->height -= delta_y, pwpChild->y += delta_y;\r
             if(pwpChild->width  < 30) pwpChild->width = 30;  // force minimum width\r
index a4d3ff2..6f2adeb 100644 (file)
@@ -1,7 +1,7 @@
 /*\r
  * woptions.c -- Options dialog box routines for WinBoard\r
  *\r
- * Copyright 2000, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.\r
+ * Copyright 2000, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.\r
  *\r
  * Enhancements Copyright 2005 Alessandro Scotti\r
  *\r
index cdc1d0d..5b70c4c 100644 (file)
@@ -1,7 +1,7 @@
 /*\r
  * woptions.h -- Options dialog box routines for WinBoard\r
  *\r
- * Copyright 2000, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.\r
+ * Copyright 2000, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.\r
  *\r
  * Enhancements Copyright 2005 Alessandro Scotti\r
  *\r
index 2cb488e..99efab5 100644 (file)
@@ -1,4 +1,27 @@
 /*\r
+ * woptions.h -- Options dialog box routines for WinBoard\r
+ *\r
+ * Copyright 2003, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.\r
+ *\r
+ * ------------------------------------------------------------------------\r
+ *\r
+ * GNU XBoard is free software: you can redistribute it and/or modify\r
+ * it under the terms of the GNU General Public License as published by\r
+ * the Free Software Foundation, either version 3 of the License, or (at\r
+ * your option) any later version.\r
+ *\r
+ * GNU XBoard is distributed in the hope that it will be useful, but\r
+ * WITHOUT ANY WARRANTY; without even the implied warranty of\r
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU\r
+ * General Public License for more details.\r
+ *\r
+ * You should have received a copy of the GNU General Public License\r
+ * along with this program. If not, see http://www.gnu.org/licenses/.  *\r
+ *\r
+ *------------------------------------------------------------------------\r
+ ** See the file ChangeLog for a revision history.  */\r
+\r
+/*\r
  * Engine-settings dialog. The complexity come from an attempt to present the engine-defined options\r
  * in a nicey formatted layout. To this end we first run a back-end pre-formatter, which will distribute\r
  * the controls over two columns (the minimum required, as some are double width). It also takes care of\r
index 24a1b4b..45775f7 100644 (file)
@@ -1,7 +1,7 @@
 /*\r
  * wsockerr.c\r
  *\r
- * Copyright 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.\r
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.\r
  * ------------------------------------------------------------------------\r
  *\r
  * GNU XBoard is free software: you can redistribute it and/or modify\r
index 8fb9741..3594f06 100644 (file)
@@ -1,7 +1,7 @@
 /*\r
  * wsockerr.h\r
  *\r
- * Copyright 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.\r
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.\r
  * ------------------------------------------------------------------------\r
  *\r
  * GNU XBoard is free software: you can redistribute it and/or modify\r
index d93743f..d3d6ba2 100644 (file)
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * The following terms apply to Digital Equipment Corporation's copyright
  * interest in XBoard:
index 04692b5..95fec39 100644 (file)
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * The following terms apply to Digital Equipment Corporation's copyright
  * interest in XBoard:
index 66d259a..d39c604 100644 (file)
@@ -5,7 +5,8 @@
  *
  * Copyright 2005 Alessandro Scotti
  *
- * Enhancements Copyright 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Enhancements Copyright 2009, 2010, 2011, 2012, 2013,
+ * 2014 Free Software Foundation, Inc.
  *
  * ------------------------------------------------------------------------
  *
index 910729d..9906f7f 100644 (file)
@@ -1,7 +1,7 @@
 /*
  * xgamelist.c -- Game list window, part of X front end for XBoard
  *
- * Copyright 1995, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Copyright 1995, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  * ------------------------------------------------------------------------
  *
  * GNU XBoard is free software: you can redistribute it and/or modify
index 5a0a5e1..cc55793 100644 (file)
@@ -1,7 +1,7 @@
 /*
  * xgamelist.h -- Game list window, part of X front end for XBoard
  *
- * Copyright 1995, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Copyright 1995, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  * ------------------------------------------------------------------------
  *
  * GNU XBoard is free software: you can redistribute it and/or modify
index edaf8c3..23ee4af 100644 (file)
@@ -1,7 +1,7 @@
 /*
  * New (WinBoard-style) Move history for XBoard
  *
- * Copyright 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Copyright 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  * ------------------------------------------------------------------------
  *
  * GNU XBoard is free software: you can redistribute it and/or modify
index e2a51ad..b3832d1 100644 (file)
@@ -1,7 +1,7 @@
 /*
  * xhistory.h -- Eval graph window, part of X front end for XBoard
  *
- * Copyright 1995, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Copyright 1995, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  * ------------------------------------------------------------------------
  *
  * GNU XBoard is free software: you can redistribute it and/or modify
index b8b64f6..1f406cb 100644 (file)
@@ -1,7 +1,7 @@
 /*
  * xoptions.c -- Move list window, part of X front end for XBoard
  *
- * Copyright 2000, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * Copyright 2000, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  * ------------------------------------------------------------------------
  *
  * GNU XBoard is free software: you can redistribute it and/or modify
@@ -988,6 +988,7 @@ GenericPopUp (Option *option, char *title, DialogClass dlgNr, DialogClass parent
            } else texts[h] = dialog = NULL; // kludge to position from left margin
            w = option[i].type == Spin || option[i].type == Fractional ? 70 : option[i].max ? option[i].max : 205;
            if(option[i].type == FileName || option[i].type == PathName) w -= 55;
+           if(squareSize > 33) w += (squareSize - 33)/2;
            j = SetPositionAndSize(args, dialog, last, 1 /* border */,
                                   w /* w */, option[i].type == TextBox ? option[i].value : 0 /* h */, 0x91 /* chain full width */);
            if(option[i].type == TextBox) { // decorations for multi-line text-edits
index 825b0f2..1616749 100644 (file)
--- a/xboard2.h
+++ b/xboard2.h
@@ -1,3 +1,25 @@
+/*
+ * xboard2.h -- Move list window, part of X front end for XBoard
+ *
+ * Copyright 2012, 2013, 2014 Free Software Foundation, Inc.
+ * ------------------------------------------------------------------------
+ *
+ * GNU XBoard is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or (at
+ * your option) any later version.
+ *
+ * GNU XBoard is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see http://www.gnu.org/licenses/.  *
+ *
+ *------------------------------------------------------------------------
+ ** See the file ChangeLog for a revision history.  */
+
 void SendToProgram P((char *message, ChessProgramState *cps));
 void SendToICS P((char *buf));
 void InitDrawingSizes P((int i, int j));
index 20836f0..065fb74 100644 (file)
@@ -50,7 +50,7 @@ tends to work poorly because it is dull when shouted in isolated
 
 * * *
 
-Unix: To build the Zippy version of xboard, on most systems just do: 
+Unix: To build the Zippy version of xboard, on most systems just do:
        configure --enable-zippy
        make
 
@@ -126,12 +126,12 @@ NEW OPTIONS
        its sayings file.  You can alias this to whatever you like.
        If XXX is censoring you, he is automatically removed from your
        notify list.
-       
+
        (3) If a player XXX in your notify list logs off, xboard sends
-       the command "farewell XXX" to ICS.  You can alias this to 
+       the command "farewell XXX" to ICS.  You can alias this to
        whatever you like.  Note that the player is already gone, so
        telling him something is futile.
-       
+
        If zippyTalk is on, colorization in the ICS interaction
        window, and the sounds corresponding to colors in that window,
        do not work.  The reply feature captures the tells, etc.,
@@ -263,7 +263,7 @@ NEW OPTIONS
         partner tells to be relayed to the engine with the ptell
         command.
 
-  -zippyMaxGames int 
+  -zippyMaxGames int
   -zippyReplayTimeout
         If zippyMaxGames > 0, Zippy will play at most the given number
        of consecutive games against the same opponent.  Thereafter,
@@ -280,8 +280,8 @@ NEW OPTIONS
        starts a game between Zippy and the first opponent to respond,
        giving Zippy no choice about whether to accept or decline.
 
-  -zippyShortGame int 
-        If zippyShortGame > 0, Zippy will decline all challenges 
+  -zippyShortGame int
+        If zippyShortGame > 0, Zippy will decline all challenges
        from an opponent that terminated a game before the given number
        of ply (with an explanatory tell) until either someone else has
        played or zippyReplayTimeout seconds have elapsed. Do not set
diff --git a/zippy.c b/zippy.c
index 09e8c7d..8796328 100644 (file)
--- a/zippy.c
+++ b/zippy.c
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
  *
diff --git a/zippy.h b/zippy.h
index c08b7a1..59a1012 100644 (file)
--- a/zippy.h
+++ b/zippy.h
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
  *
index 247b127..60fc8b4 100644 (file)
@@ -23,8 +23,8 @@ more than 250 characters long, it will never be used.  This is an
 extra sentence to make the saying more than 250 characters long so
 that the previous sentence will be true.
 ^
-The eighth item to know is that when you are testing, you had better have 
-several valid sayings in your file; for various reasons, having too few 
+The eighth item to know is that when you are testing, you had better have
+several valid sayings in your file; for various reasons, having too few
 sayings can cause Zippy to get into an endless loop, or to be very slow.
 ^
 As the ninth and final saying, let me add that you need a caret
--- a/common.h
+++ b/common.h
@@ -5,7 +5,7 @@
  * Massachusetts.
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
* 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
  *
@@ -112,6 +112,46 @@ typedef char *String;
 
 /* End compatibility grunge */
 
+/* unsigned int 64 for engine nodes work and display */
+#ifdef WIN32
+       /* I don't know the name for this type of other compiler
+        * If it not work, just modify here
+        * This is for MS Visual Studio
+        */
+       #ifdef _MSC_VER
+               #define u64 unsigned __int64
+               #define s64 signed __int64
+               #define u64Display "%I64u"
+               #define s64Display "%I64d"
+               #define u64Const(c) (c ## UI64)
+               #define s64Const(c) (c ## I64)
+       #else
+               /* place holder
+                * or dummy types for other compiler
+                * [HGM] seems that -mno-cygwin comple needs %I64?
+                */
+               #define u64 unsigned long long
+               #define s64 signed long long
+               #ifdef USE_I64
+                  #define u64Display "%I64u"
+                  #define s64Display "%I64d"
+               #else
+                  #define u64Display "%llu"
+                  #define s64Display "%lld"
+               #endif
+               #define u64Const(c) (c ## ULL)
+               #define s64Const(c) (c ## LL)
+       #endif
+#else
+       /* GNU gcc */
+       #define u64 unsigned long long
+       #define s64 signed long long
+       #define u64Display "%llu"
+       #define s64Display "%lld"
+       #define u64Const(c) (c ## ull)
+       #define s64Const(c) (c ## ll)
+#endif
+
 #define PROTOVER                2       /* engine protocol version */
 
 // [HGM] license: Messages that engines must print to satisfy their license requirements for patented variants
index 4b679fa..5189be7 100644 (file)
@@ -1,7 +1,7 @@
 dnl| configure.in
 dnl|
 dnl| Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006, 2007,
-dnl| 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+dnl| 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
 dnl|
 dnl| GNU XBoard is free software: you can redistribute it and/or modify
 dnl| it under the terms of the GNU General Public License as published by
index b5032f2..25da1ca 100644 (file)
@@ -22,7 +22,7 @@ arising out of or in connection with the use or performance of this
 software.
 
 Enhancements copyright @copyright{} 1992-2003, 2004, 2005, 2006, 2007,
-2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
 
 @format
 Published by the Free Software Foundation
@@ -5,7 +5,7 @@
  *
  * Enhancements Copyright 1992-2001, 2002, 2003, 2004, 2005, 2006,
- * 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+ * 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Free Software Foundation, Inc.
  *
  * Enhancements Copyright 2005 Alessandro Scotti
index 5aec3fd..57b7142 100644 (file)